@@ -1,6 +1,6 @@
 test_that("write_gtfs", {
     poa <- read_gtfs(system.file("extdata/poa.zip", package="gtfs2gps"))
-
+    
     write_gtfs(poa, "poa2.zip")
     
     poa <- read_gtfs("poa2.zip")
@@ -8,12 +8,12 @@ test_that("write_gtfs", {
     expect_type(poa, "list")
     expect_equal(length(poa), 7)
     
-    expect_equal(length(poa$agency), 7)
-    expect_equal(length(poa$routes), 9)
+    expect_true(length(poa$agency) >= 1)
+    expect_equal(length(poa$routes), 3)
     expect_equal(length(poa$stops), 6)
     expect_equal(length(poa$stop_times), 5)
     expect_equal(length(poa$shapes), 4)
-    expect_equal(length(poa$trips), 10)
+    expect_equal(length(poa$trips), 4)
     expect_equal(length(poa$calendar), 10)
     
     expect_equal(dim(poa$shapes)[1], 1265)
@@ -32,15 +32,15 @@ test_that("write_gtfs", {
     expect_equal(length(sp), 8)
     
     expect_equal(length(sp$agency), 5)
-    expect_equal(length(sp$routes), 7)
+    expect_equal(length(sp$routes), 3)
     expect_equal(length(sp$stops), 5)
     expect_equal(length(sp$stop_times), 5)
-    expect_equal(length(sp$shapes), 5)
-    expect_equal(length(sp$trips), 6)
+    expect_equal(length(sp$shapes), 4)
+    expect_equal(length(sp$trips),4)
     expect_equal(length(sp$calendar), 10)
     
     expect_equal(dim(sp$shapes)[1], 35886)
     expect_equal(dim(sp$trips)[1], 92)
     
     invisible(file.remove("sp2.zip"))
-})
+})
\ No newline at end of file
